@@ -116,10 +116,11 @@ class MaskFormerHead(AnchorFreeHead):
         self.test_cfg = test_cfg
         self.train_cfg = train_cfg
         if train_cfg:
-            self.assigner = build_assigner(train_cfg.assigner)
-            self.sampler = build_sampler(train_cfg.sampler, context=self)
+            self.assigner = build_assigner(train_cfg.get('assigner', None))
+            self.sampler = build_sampler(
+                train_cfg.get('sampler', None), context=self)
 
-        self.class_weight = loss_cls.class_weight
+        self.class_weight = loss_cls.get('class_weight', None)
         self.loss_cls = build_loss(loss_cls)
         self.loss_mask = build_loss(loss_mask)
         self.loss_dice = build_loss(loss_dice)
