@@ -141,7 +141,9 @@ class MaskFeatModule(BaseModule):
                                                  input_p.device)
                 input_p = torch.cat([input_p, coord_feat], 1)
 
-            feature_add_all_level += self.convs_all_levels[i](input_p)
+            # fix runtime error of "+=" inplace operation in PyTorch 1.10
+            feature_add_all_level = feature_add_all_level + \
+                self.convs_all_levels[i](input_p)
 
         feature_pred = self.conv_pred(feature_add_all_level)
         return feature_pred
